==> crisis-management-resources-v0.2-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/CarProviderEventImplementationManager.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import java.util.logging.Logger;
import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.xml.bind.annotation.XmlSeeAlso;
import com.petalslink.wsn.service.wsnproducer.NotificationProducer;
import org.petalslink.easiestdemo.wsoui.provided.AbstractImplementationManager;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.wsoui.context.WSOUIJaxbContext;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;
import org.petalslink.easiestdemo.wsoui.provided.notification.SubscriptionManager;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.Subscribe;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.SubscribeResponse;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.refinedabstraction.RefinedWsnbFactory;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.utils.WsnbException;
import org.w3c.dom.Document;
import java.net.URL;
import java.util.Enumeration;
import com.ebmwebsourcing.easycommons.research.util.jaxb.SOAJAXBContext;
import java.lang.InterruptedException;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
@javax.jws.WebService(
	wsdlLocation = "crisis/v3/./carProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	endpointInterface = "com.petalslink.wsn.service.wsnproducer.NotificationProducer",
	portName = "carProviderEventPort",
	serviceName = "carProviderEvent")
public class CarProviderEventImplementationManager extends AbstractImplementationManager<NotificationProducer> implements NotificationProducer{

	private AbstractEventProducerNotifier eventProducer = null;
	private WSOUIJaxbContextItf context = null;

	public CarProviderEventImplementationManager(AbstractTestImplementation ti, URL wsdl) throws WSOUIException {
		super(ti, wsdl);
		context = new WSOUIJaxbContext();
		this.eventProducer = new CarProviderEvent_EventProducerNotifier(this.getConfiguration(), context);
	}

	public CarProviderEventImplementationManager(AbstractTestImplementation ti, URL wsdl, ProviderConfiguration configuration) throws WSOUIException {
		super(ti, wsdl, configuration);
		context = new WSOUIJaxbContext();
		this.eventProducer = new CarProviderEvent_EventProducerNotifier(this.getConfiguration(), context);
	}

	public easybox.org.oasis_open.docs.wsn.b_2.EJaxbGetCurrentMessageResponse getCurrentMessage(easybox.org.oasis_open.docs.wsn.b_2.EJaxbGetCurrentMessage getCurrentMessageRequest)  throws org.oasis_open.docs.wsn.bw_2.TopicNotSupportedFault, org.oasis_open.docs.wsn.bw_2.InvalidTopicExpressionFault, org.oasis_open.docs.wsrf.rw_2.ResourceUnknownFault, org.oasis_open.docs.wsn.bw_2.TopicExpressionDialectUnknownFault, org.oasis_open.docs.wsn.bw_2.NoCurrentMessageOnTopicFault, org.oasis_open.docs.wsn.bw_2.MultipleTopicsSpecifiedFault {
		easybox.org.oasis_open.docs.wsn.b_2.EJaxbGetCurrentMessageResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("getCurrentMessage" ,getCurrentMessageRequest);
		response = this.getTestImplementation().getCurrentMessage(getCurrentMessageRequest);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("carProviderEvent", "carProviderEventPort", "getCurrentMessage", getCurrentMessageRequest, response, easybox.org.oasis_open.docs.wsn.b_2.EJaxbGetCurrentMessageResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (easybox.org.oasis_open.docs.wsn.b_2.EJaxbGetCurrentMessageResponse) this.getGuiImplementation().getResponse();
		}
			 else {
					 org.oasis_open.docs.wsn.bw_2.TopicNotSupportedFault exx = new org.oasis_open.docs.wsn.bw_2.TopicNotSupportedFault(this.getGuiImplementation().getResponse().toString());
					 throw exx;}		}
		eventProducer.sendEventBeforeSendResponse("getCurrentMessage" ,getCurrentMessageRequest, response);
		return response;
	}


	public easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribeResponse subscribe(easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribe subscribeRequest)  throws org.oasis_open.docs.wsn.bw_2.NotifyMessageNotSupportedFault, org.oasis_open.docs.wsn.bw_2.TopicNotSupportedFault, org.oasis_open.docs.wsn.bw_2.InvalidFilterFault, org.oasis_open.docs.wsn.bw_2.InvalidTopicExpressionFault, org.oasis_open.docs.wsrf.rw_2.ResourceUnknownFault, org.oasis_open.docs.wsn.bw_2.TopicExpressionDialectUnknownFault, org.oasis_open.docs.wsn.bw_2.UnrecognizedPolicyRequestFault, org.oasis_open.docs.wsn.bw_2.SubscribeCreationFailedFault, org.oasis_open.docs.wsn.bw_2.InvalidMessageContentExpressionFault, org.oasis_open.docs.wsn.bw_2.UnsupportedPolicyRequestFault, org.oasis_open.docs.wsn.bw_2.UnacceptableInitialTerminationTimeFault, org.oasis_open.docs.wsn.bw_2.InvalidProducerPropertiesExpressionFault {
		easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribeResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("subscribe" ,subscribeRequest);
		response = this.getTestImplementation().subscribe(subscribeRequest);
		if(response == null) {
			try {
				response = eventProducer.getSubscriptionManager().subscribe(subscribeRequest);
			} catch (WsnbException e) {
				throw new org.oasis_open.docs.wsn.bw_2.NotifyMessageNotSupportedFault(e.getMessage(), e);
			}
		}
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("carProviderEvent", "carProviderEventPort", "subscribe", subscribeRequest, response, easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribeResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribeResponse) this.getGuiImplementation().getResponse();
		}
			 else {
					 org.oasis_open.docs.wsn.bw_2.NotifyMessageNotSupportedFault exx = new org.oasis_open.docs.wsn.bw_2.NotifyMessageNotSupportedFault(this.getGuiImplementation().getResponse().toString());
					 throw exx;}		}
		eventProducer.sendEventBeforeSendResponse("subscribe" ,subscribeRequest, response);
		return response;
	}


	public easybox.org.oasis_open.docs.wsrf.rp_2.EJaxbGetResourcePropertyResponse getResourceProperty(javax.xml.namespace.QName getResourcePropertyRequest)  throws org.oasis_open.docs.wsrf.rw_2.ResourceUnknownFault, org.oasis_open.docs.wsrf.rpw_2.InvalidResourcePropertyQNameFault, org.oasis_open.docs.wsrf.rw_2.ResourceUnavailableFault {
		easybox.org.oasis_open.docs.wsrf.rp_2.EJaxbGetResourcePropertyResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("getResourceProperty" ,getResourcePropertyRequest);
		response = this.getTestImplementation().getResourceProperty(getResourcePropertyRequest);
		if(response == null) {
			if(getResourcePropertyRequest == null) {
				throw new org.oasis_open.docs.wsrf.rpw_2.InvalidResourcePropertyQNameFault("Property cannot be null");
			}
			if(getResourcePropertyRequest.getLocalPart().equals("TopicSet")) {
				Document topicSetDoc = eventProducer.getSubscriptionManager().getTopicSetDocument();
				response = new easybox.org.oasis_open.docs.wsrf.rp_2.EJaxbGetResourcePropertyResponse();
				if(topicSetDoc != null) {
					response.getAny().add(topicSetDoc.getDocumentElement());
				}
			} else {
				throw new org.oasis_open.docs.wsrf.rpw_2.InvalidResourcePropertyQNameFault(getResourcePropertyRequest.getLocalPart() + " property unknown");
			}
		}
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("carProviderEvent", "carProviderEventPort", "getResourceProperty", getResourcePropertyRequest, response, easybox.org.oasis_open.docs.wsrf.rp_2.EJaxbGetResourcePropertyResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (easybox.org.oasis_open.docs.wsrf.rp_2.EJaxbGetResourcePropertyResponse) this.getGuiImplementation().getResponse();
		}
			 else {
					 org.oasis_open.docs.wsrf.rw_2.ResourceUnknownFault exx = new org.oasis_open.docs.wsrf.rw_2.ResourceUnknownFault(this.getGuiImplementation().getResponse().toString());
					 throw exx;}		}
		eventProducer.sendEventBeforeSendResponse("getResourceProperty" ,getResourcePropertyRequest, response);
		return response;
	}



}

==> crisis-management-resources-v0.4-sources.jar: fr/mines_albi/nuclearcrisisevent/provider/CarProviderEventImplementationManager.java <==
package fr.mines_albi.nuclearcrisisevent.provider;

import java.util.logging.Logger;
import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.jws.soap.SOAPBinding;
import javax.xml.bind.annotation.XmlSeeAlso;
import com.petalslink.wsn.service.wsnproducer.NotificationProducer;
import org.petalslink.easiestdemo.wsoui.provided.AbstractImplementationManager;
import org.petalslink.easiestdemo.wsoui.provided.AbstractTestImplementation;
import org.petalslink.easiestdemo.wsoui.provided.WSOUIJaxbContextItf;
import org.petalslink.easiestdemo.wsoui.provided.ProviderConfiguration;
import org.petalslink.easiestdemo.wsoui.core.WSOUIException;
import org.petalslink.wsoui.context.WSOUIJaxbContext;
import org.petalslink.easiestdemo.wsoui.provided.notification.AbstractEventProducerNotifier;
import org.petalslink.easiestdemo.wsoui.provided.notification.SubscriptionManager;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.Subscribe;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.abstraction.SubscribeResponse;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.refinedabstraction.RefinedWsnbFactory;
import com.ebmwebsourcing.wsstar.basenotification.datatypes.api.utils.WsnbException;
import org.w3c.dom.Document;
import java.net.URL;
import java.util.Enumeration;
import com.ebmwebsourcing.easycommons.research.util.jaxb.SOAJAXBContext;
import java.lang.InterruptedException;
import java.net.URLClassLoader;
import java.util.ArrayList;
import java.util.List;
import java.io.File;
@javax.jws.WebService(
	wsdlLocation = "crisis/management/generated/./carProvider.wsdl",
	targetNamespace = "http://www.mines-albi.fr/nuclearcrisisevent/provider",
	endpointInterface = "com.petalslink.wsn.service.wsnproducer.NotificationProducer",
	portName = "carProviderEventPort",
	serviceName = "carProviderEvent")
public class CarProviderEventImplementationManager extends AbstractImplementationManager<NotificationProducer> implements NotificationProducer{

	private AbstractEventProducerNotifier eventProducer = null;
	private WSOUIJaxbContextItf context = null;

	public CarProviderEventImplementationManager(AbstractTestImplementation ti, URL wsdl) throws WSOUIException {
		super(ti, wsdl);
		context = new WSOUIJaxbContext();
		this.eventProducer = new CarProviderEvent_EventProducerNotifier(this.getConfiguration(), context);
	}

	public CarProviderEventImplementationManager(AbstractTestImplementation ti, URL wsdl, ProviderConfiguration configuration) throws WSOUIException {
		super(ti, wsdl, configuration);
		context = new WSOUIJaxbContext();
		this.eventProducer = new CarProviderEvent_EventProducerNotifier(this.getConfiguration(), context);
	}

	public easybox.org.oasis_open.docs.wsn.b_2.EJaxbGetCurrentMessageResponse getCurrentMessage(easybox.org.oasis_open.docs.wsn.b_2.EJaxbGetCurrentMessage getCurrentMessageRequest)  throws org.oasis_open.docs.wsn.bw_2.TopicNotSupportedFault, org.oasis_open.docs.wsn.bw_2.InvalidTopicExpressionFault, org.oasis_open.docs.wsrf.rw_2.ResourceUnknownFault, org.oasis_open.docs.wsn.bw_2.TopicExpressionDialectUnknownFault, org.oasis_open.docs.wsn.bw_2.NoCurrentMessageOnTopicFault, org.oasis_open.docs.wsn.bw_2.MultipleTopicsSpecifiedFault {
		easybox.org.oasis_open.docs.wsn.b_2.EJaxbGetCurrentMessageResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("getCurrentMessage" ,getCurrentMessageRequest);
		response = this.getTestImplementation().getCurrentMessage(getCurrentMessageRequest);
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("carProviderEvent", "carProviderEventPort", "getCurrentMessage", getCurrentMessageRequest, response, easybox.org.oasis_open.docs.wsn.b_2.EJaxbGetCurrentMessageResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (easybox.org.oasis_open.docs.wsn.b_2.EJaxbGetCurrentMessageResponse) this.getGuiImplementation().getResponse();
		}
			 else {
					 org.oasis_open.docs.wsn.bw_2.TopicNotSupportedFault exx = new org.oasis_open.docs.wsn.bw_2.TopicNotSupportedFault(this.getGuiImplementation().getResponse().toString());
					 throw exx;}		}
		eventProducer.sendEventBeforeSendResponse("getCurrentMessage" ,getCurrentMessageRequest, response);
		return response;
	}


	public easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribeResponse subscribe(easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribe subscribeRequest)  throws org.oasis_open.docs.wsn.bw_2.NotifyMessageNotSupportedFault, org.oasis_open.docs.wsn.bw_2.TopicNotSupportedFault, org.oasis_open.docs.wsn.bw_2.InvalidFilterFault, org.oasis_open.docs.wsn.bw_2.InvalidTopicExpressionFault, org.oasis_open.docs.wsrf.rw_2.ResourceUnknownFault, org.oasis_open.docs.wsn.bw_2.TopicExpressionDialectUnknownFault, org.oasis_open.docs.wsn.bw_2.UnrecognizedPolicyRequestFault, org.oasis_open.docs.wsn.bw_2.SubscribeCreationFailedFault, org.oasis_open.docs.wsn.bw_2.InvalidMessageContentExpressionFault, org.oasis_open.docs.wsn.bw_2.UnsupportedPolicyRequestFault, org.oasis_open.docs.wsn.bw_2.UnacceptableInitialTerminationTimeFault, org.oasis_open.docs.wsn.bw_2.InvalidProducerPropertiesExpressionFault {
		easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribeResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("subscribe" ,subscribeRequest);
		response = this.getTestImplementation().subscribe(subscribeRequest);
		if(response == null) {
			try {
				response = eventProducer.getSubscriptionManager().subscribe(subscribeRequest);
			} catch (WsnbException e) {
				throw new org.oasis_open.docs.wsn.bw_2.NotifyMessageNotSupportedFault(e.getMessage(), e);
			}
		}
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("carProviderEvent", "carProviderEventPort", "subscribe", subscribeRequest, response, easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribeResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (easybox.org.oasis_open.docs.wsn.b_2.EJaxbSubscribeResponse) this.getGuiImplementation().getResponse();
		}
			 else {
					 org.oasis_open.docs.wsn.bw_2.NotifyMessageNotSupportedFault exx = new org.oasis_open.docs.wsn.bw_2.NotifyMessageNotSupportedFault(this.getGuiImplementation().getResponse().toString());
					 throw exx;}		}
		eventProducer.sendEventBeforeSendResponse("subscribe" ,subscribeRequest, response);
		return response;
	}


	public easybox.org.oasis_open.docs.wsrf.rp_2.EJaxbGetResourcePropertyResponse getResourceProperty(javax.xml.namespace.QName getResourcePropertyRequest)  throws org.oasis_open.docs.wsrf.rw_2.ResourceUnknownFault, org.oasis_open.docs.wsrf.rpw_2.InvalidResourcePropertyQNameFault, org.oasis_open.docs.wsrf.rw_2.ResourceUnavailableFault {
		easybox.org.oasis_open.docs.wsrf.rp_2.EJaxbGetResourcePropertyResponse response = null;
		eventProducer.sendEventBeforeProcessingRequest("getResourceProperty" ,getResourcePropertyRequest);
		response = this.getTestImplementation().getResourceProperty(getResourcePropertyRequest);
		if(response == null) {
			if(getResourcePropertyRequest == null) {
				throw new org.oasis_open.docs.wsrf.rpw_2.InvalidResourcePropertyQNameFault("Property cannot be null");
			}
			if(getResourcePropertyRequest.getLocalPart().equals("TopicSet")) {
				Document topicSetDoc = eventProducer.getSubscriptionManager().getTopicSetDocument();
				response = new easybox.org.oasis_open.docs.wsrf.rp_2.EJaxbGetResourcePropertyResponse();
				if(topicSetDoc != null) {
					response.getAny().add(topicSetDoc.getDocumentElement());
				}
			} else {
				throw new org.oasis_open.docs.wsrf.rpw_2.InvalidResourcePropertyQNameFault(getResourcePropertyRequest.getLocalPart() + " property unknown");
			}
		}
		if(this.isActivateGUI()) {
		  this.getGuiImplementation().setWsouiContext(context);
		  this.getGuiImplementation().setExchangeInformations("carProviderEvent", "carProviderEventPort", "getResourceProperty", getResourcePropertyRequest, response, easybox.org.oasis_open.docs.wsrf.rp_2.EJaxbGetResourcePropertyResponse.class, this.getGuiImplementation().getResponseType());
		  this.getGuiImplementation().setVisible(true);
		  synchronized(this.lock) {
			  try {				  this.lock.wait();
			  } catch(InterruptedException ie) {
				  		// do nothing
				  		ie.printStackTrace();
			  }
		  }
		 if(this.getGuiImplementation().getResponseType().equals("out")){
			  response = (easybox.org.oasis_open.docs.wsrf.rp_2.EJaxbGetResourcePropertyResponse) this.getGuiImplementation().getResponse();
		}
			 else {
					 org.oasis_open.docs.wsrf.rw_2.ResourceUnknownFault exx = new org.oasis_open.docs.wsrf.rw_2.ResourceUnknownFault(this.getGuiImplementation().getResponse().toString());
					 throw exx;}		}
		eventProducer.sendEventBeforeSendResponse("getResourceProperty" ,getResourcePropertyRequest, response);
		return response;
	}



}
